import { PostgrestQueryBuilder, PostgrestSingleResponse, PostgrestMaybeSingleResponse, PostgrestResponse, PostgrestFilterBuilder } from '@supabase/postgrest-js';
import { GetResult } from '@supabase/postgrest-js/dist/module/select-query-parser';
import { GenericTable } from '@supabase/postgrest-js/dist/module/types';

declare const buildDeleteFetcher: <T extends GenericTable, Q extends string = "*", R = GetResult<T["Row"], Q extends "*" ? "*" : Q>>(qb: PostgrestQueryBuilder<T>, primaryKeys: (keyof T["Row"])[], query?: Q | undefined) => (input: Partial<T["Row"]>) => Promise<R>;

declare type FetcherType = "single" | "maybeSingle" | "multiple";
declare type PostgrestFetcherResponse<Type> = Pick<PostgrestSingleResponse<Type>, "data"> | Pick<PostgrestMaybeSingleResponse<Type>, "data"> | Pick<PostgrestResponse<Type>, "data" | "count">;
declare function createFetcher<Table extends Record<string, unknown>, Result>(mode: FetcherType): (query: PostgrestFilterBuilder<Table, Result>) => Promise<PostgrestFetcherResponse<Result>>;

declare const buildInsertFetcher: <T extends GenericTable, Q extends string = "*", R = GetResult<T["Row"], Q extends "*" ? "*" : Q>>(qb: PostgrestQueryBuilder<T>, mode: "single" | "multiple", query?: Q | undefined) => (input: T["Insert"] | T["Insert"][]) => Promise<R | R[]>;

declare type PostgrestPaginationFetcher<Type, Args extends any[]> = (...args: Args) => Promise<Type[] | null>;
declare type PostgrestPaginationKeyDecoder<Args extends any[]> = (...args: Args) => {
    limit?: number;
    offset?: number;
};
declare const createPaginationFetcher: <Table extends Record<string, unknown>, Result extends Record<string, unknown>, Args extends any[]>(query: PostgrestFilterBuilder<Table, Result> | null, decode: PostgrestPaginationKeyDecoder<Args>, pageSize: number) => PostgrestPaginationFetcher<Result, Args> | null;
declare const createPaginationHasMoreFetcher: <Table extends Record<string, unknown>, Result, Args extends any[]>(query: PostgrestFilterBuilder<Table, Result> | null, decode: PostgrestPaginationKeyDecoder<Args>, pageSize: number) => PostgrestPaginationFetcher<Result | {
    hasMore: true;
}, Args> | null;

declare const buildUpdateFetcher: <T extends GenericTable, Q extends string = "*", R = GetResult<T["Row"], Q extends "*" ? "*" : Q>>(qb: PostgrestQueryBuilder<T>, primaryKeys: (keyof T["Row"])[], query?: Q | undefined) => (input: Partial<T["Row"]>) => Promise<R>;

declare const buildUpsertFetcher: <T extends GenericTable, Q extends string = "*", R = GetResult<T["Row"], Q extends "*" ? "*" : Q>>(qb: PostgrestQueryBuilder<T>, mode: "single" | "multiple", query?: Q | undefined) => (input: T["Insert"] | T["Insert"][]) => Promise<R | R[]>;

export { FetcherType, PostgrestFetcherResponse, PostgrestPaginationFetcher, PostgrestPaginationKeyDecoder, buildDeleteFetcher, buildInsertFetcher, buildUpdateFetcher, buildUpsertFetcher, createFetcher, createPaginationFetcher, createPaginationHasMoreFetcher };
