"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  buildDeleteFetcher: () => buildDeleteFetcher,
  buildInsertFetcher: () => buildInsertFetcher,
  buildUpdateFetcher: () => buildUpdateFetcher,
  buildUpsertFetcher: () => buildUpsertFetcher,
  createFetcher: () => createFetcher,
  createPaginationFetcher: () => createPaginationFetcher,
  createPaginationHasMoreFetcher: () => createPaginationHasMoreFetcher
});
module.exports = __toCommonJS(src_exports);

// src/delete.ts
var buildDeleteFetcher = (qb, primaryKeys, query) => async (input) => {
  let filterBuilder = qb.delete();
  for (const key of primaryKeys) {
    const value = input[key];
    if (!value)
      throw new Error(`Missing value for primary key ${String(key)}`);
    filterBuilder = filterBuilder.eq(key, value);
  }
  const { data } = await filterBuilder.select(query ?? "*").throwOnError().single();
  return data;
};

// src/fetcher.ts
function createFetcher(mode) {
  return async (query) => {
    if (mode === "single") {
      const { data: data2 } = await query.throwOnError().single();
      return { data: data2 };
    }
    if (mode === "maybeSingle") {
      const { data: data2 } = await query.throwOnError().maybeSingle();
      return { data: data2 };
    }
    const { data, count } = await query.throwOnError();
    return { data, count };
  };
}

// src/insert.ts
var buildInsertFetcher = (qb, mode, query) => async (input) => {
  if (!Array.isArray(input))
    input = [input];
  const filterBuilder = qb.insert(input).throwOnError().select(query ?? "*");
  if (mode === "single") {
    const { data } = await filterBuilder.single();
    return data;
  } else {
    const { data } = await filterBuilder;
    return data;
  }
};

// src/pagination-fetcher.ts
var createPaginationFetcher = (query, decode, pageSize) => {
  if (!query)
    return null;
  return async (...args) => {
    const decodedKey = decode(...args);
    const limit = (decodedKey.limit ?? pageSize) - 1;
    const offset = decodedKey.offset ?? 0;
    const { data } = await query.range(offset, offset + limit).throwOnError();
    return data;
  };
};
var createPaginationHasMoreFetcher = (query, decode, pageSize) => {
  if (!query)
    return null;
  return async (...args) => {
    const decodedKey = decode(...args);
    const limit = decodedKey.limit ?? pageSize;
    const offset = decodedKey.offset ?? 0;
    const result = await query.range(offset, offset + limit).throwOnError();
    const data = result.data;
    if (data && data.length === pageSize + 1) {
      data[data.length - 1] = { hasMore: true };
    }
    return data;
  };
};

// src/update.ts
var buildUpdateFetcher = (qb, primaryKeys, query) => async (input) => {
  let filterBuilder = qb.update(input);
  for (const key of primaryKeys) {
    const value = input[key];
    if (!value)
      throw new Error(`Missing value for primary key ${String(key)}`);
    filterBuilder = filterBuilder.eq(key, value);
  }
  const { data } = await filterBuilder.select(query ?? "*").throwOnError().single();
  return data;
};

// src/upsert.ts
var buildUpsertFetcher = (qb, mode, query) => async (input) => {
  if (!Array.isArray(input))
    input = [input];
  const filterBuilder = qb.upsert(input).throwOnError().select(query ?? "*");
  if (mode === "single") {
    const { data } = await filterBuilder.single();
    return data;
  } else {
    const { data } = await filterBuilder;
    return data;
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  buildDeleteFetcher,
  buildInsertFetcher,
  buildUpdateFetcher,
  buildUpsertFetcher,
  createFetcher,
  createPaginationFetcher,
  createPaginationHasMoreFetcher
});
//# sourceMappingURL=index.js.map